<!-- Copyright: © 2024 Jonathan Fox
License: GNU AGPL, version 3 or later; http://www.gnu.org/licenses/agpl.html
Full source code: https://github.com/jonathanfox5/gogadget -->

[gogadget](https://github.com/jonathanfox5/gogadget) is Copyright © 2024 Jonathan Fox.

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version. This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details. You should have received a copy of the GNU Affero General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.

All materials in this repository are covered by the aforementioned license, unless specifically noted below:

- [src/gogadget/ytdlp_cli_to_api.py](https://github.com/jonathanfox5/gogadget/blob/main/gogadget/ytdlp_cli_to_api.py) has been directly reproduced from [yt-dlp's github page](https://github.com/yt-dlp/yt-dlp/blob/master/devscripts/cli_to_api.py) ([license](https://raw.githubusercontent.com/yt-dlp/yt-dlp/refs/heads/master/LICENSE)) without modification.
- The Windows installer bundles the binaries for both [FFMPEG](https://ffmpeg.org) ([license](https://ffmpeg.org/legal.html)) and [uv](https://github.com/astral-sh/uv) ([license](https://github.com/astral-sh/uv/blob/main/LICENSE-MIT)).
- The [Bootstrap framework](https://getbootstrap.com) javascript and CSS files stored within [src/gogadget/resources/html/bootstrap](https://github.com/jonathanfox5/gogadget/tree/main/src/gogadget/resources/html/bootstrap) have been directly reproduced without modification ([license](https://github.com/twbs/bootstrap/blob/main/LICENSE)).
- Portions of [src/gogadget/resources/html/anki/](https://github.com/jonathanfox5/gogadget/tree/main/src/gogadget/resources/html/anki) have been based upon the formatting of Refold's [excellent decks](https://refold.la/category/decks/). These are APLGv3 licensed, based upon the included code from [Ankitects](https://github.com/ankitects/anki) ([license](https://github.com/ankitects/anki/blob/main/LICENSE)). Please see the individual source files for specific licensing information.
